@@ -10,9 +10,9 @@ if TYPE_CHECKING:
     from hatch.cli.application import Application
 
 
-@click.command(short_help='Update Python distributions')
-@click.argument('names', required=True, nargs=-1)
-@click.option('--dir', '-d', 'directory', help='The directory in which distributions reside')
+@click.command(short_help="Update Python distributions")
+@click.argument("names", required=True, nargs=-1)
+@click.option("--dir", "-d", "directory", help="The directory in which distributions reside")
 @click.pass_context
 def update(ctx: click.Context, *, names: tuple[str, ...], directory: str | None):
     """
@@ -29,10 +29,10 @@ def update(ctx: click.Context, *, names: tuple[str, ...], directory: str | None)
 
     manager = app.get_python_manager(directory)
     installed = manager.get_installed()
-    selection = tuple(installed) if 'all' in names else names
+    selection = tuple(installed) if "all" in names else names
 
     not_installed = [name for name in selection if name not in installed]
     if not_installed:
-        app.abort(f'Distributions not installed: {", ".join(not_installed)}')
+        app.abort(f"Distributions not installed: {', '.join(not_installed)}")
 
     ctx.invoke(install, names=selection, directory=directory, private=True, update=True)
