@@ -13,7 +13,7 @@ class EnvironmentContextFormatterBase(ContextFormatter, ABC):
 class EnvironmentContextFormatter(EnvironmentContextFormatterBase):
     def __init__(self, environment):
         self.environment = environment
-        self.CONTEXT_NAME = f'environment_{environment.PLUGIN_NAME}'
+        self.CONTEXT_NAME = f"environment_{environment.PLUGIN_NAME}"
 
     def formatters(self):  # noqa: PLR6301
         """
@@ -27,11 +27,11 @@ class EnvironmentContextFormatter(EnvironmentContextFormatterBase):
 
     def get_formatters(self):
         formatters = {
-            'args': self.__format_args,
-            'env_name': self.__format_env_name,
-            'env_type': self.__format_env_type,
-            'matrix': self.__format_matrix,
-            'verbosity': self.__format_verbosity,
+            "args": self.__format_args,
+            "env_name": self.__format_env_name,
+            "env_type": self.__format_env_type,
+            "matrix": self.__format_matrix,
+            "verbosity": self.__format_verbosity,
         }
         formatters.update(self.formatters())
         return formatters
@@ -40,7 +40,7 @@ class EnvironmentContextFormatter(EnvironmentContextFormatterBase):
         if value is not None:
             return value
 
-        return data or ''
+        return data or ""
 
     def __format_env_name(self, value, data):  # noqa: ARG002
         return self.environment.name
@@ -50,15 +50,15 @@ class EnvironmentContextFormatter(EnvironmentContextFormatterBase):
 
     def __format_matrix(self, value, data):  # noqa: ARG002
         if not data:
-            message = 'The `matrix` context formatting field requires a modifier'
+            message = "The `matrix` context formatting field requires a modifier"
             raise ValueError(message)
 
-        variable, separator, default = data.partition(':')
+        variable, separator, default = data.partition(":")
         if variable in self.environment.matrix_variables:
             return self.environment.matrix_variables[variable]
 
         if not separator:
-            message = f'Nonexistent matrix variable must set a default: {variable}'
+            message = f"Nonexistent matrix variable must set a default: {variable}"
             raise ValueError(message)
 
         return default
@@ -67,18 +67,18 @@ class EnvironmentContextFormatter(EnvironmentContextFormatterBase):
         if not data:
             return str(self.environment.verbosity)
 
-        modifier, _, adjustment = data.partition(':')
-        if modifier != 'flag':
-            message = f'Unknown verbosity modifier: {modifier}'
+        modifier, _, adjustment = data.partition(":")
+        if modifier != "flag":
+            message = f"Unknown verbosity modifier: {modifier}"
             raise ValueError(message)
 
         if not adjustment:
-            adjustment = '0'
+            adjustment = "0"
 
         try:
             adjustment = int(adjustment)
         except ValueError:
-            message = f'Verbosity flag adjustment must be an integer: {adjustment}'
+            message = f"Verbosity flag adjustment must be an integer: {adjustment}"
             raise TypeError(message) from None
 
         return get_verbosity_flag(self.environment.verbosity, adjustment=adjustment)
