@@ -5,6 +5,6 @@ from typing import Any
 
 def get_default_config() -> dict[str, Any]:
     return {
-        'skip-install': True,
-        'installer': 'uv',
+        "skip-install": True,
+        "installer": "uv",
     }
