@@ -8,4 +8,4 @@ class TestsPackageRoot(File):
         template_config: dict,  # noqa: ARG002
         plugin_config: dict,  # noqa: ARG002
     ):
-        super().__init__(Path('tests', '__init__.py'))
+        super().__init__(Path("tests", "__init__.py"))
